@@ -581,10 +581,15 @@ from pydantic import BaseModel
 
 class Model(BaseModel):
     a: ClassVar[int]
+    _b: ClassVar[int]
+    _c: ClassVar[Forward]
+
+Forward = int
 """
     )
 
-    assert module.Model.__class_vars__ == {'a'}
+    assert module.Model.__class_vars__ == {'a', '_b', '_c'}
+    assert module.Model.__private_attributes__ == {}
 
 
 def test_json_encoder_str(create_module):
